/****************************************************  Channel Defaults  *****************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following defaults are assigned to structures defined in the common functions header.

	Rev History: 1-10-2014:		Inital release.

	Copyright 2014, Red Rapids, Inc.

****************************************************  Channel Defaults  *****************************************************/

#ifndef _CHANNEL_DEFAULTS_H_
#define _CHANNEL_DEFAULTS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Initialize a default structure for the RX channels.
s_Channel RXDefault = {
	{ // Synchronizer
		1,	// StartEvent					Event that will activate the channel. - Range: 0 (none/immediate), 1 (software trigger), 2 (hardware trigger)
		3,	// StopEvent					Event that will deactivate the channel. - Range: 0 (flow control), 1 (software trigger), 2 (hardware trigger), 3 (sample count)
		16384	// SampleCount			Number of samples to collect when sample count is selected for the synchronizer StartEvent. - Range: 0 to (2^32 - 1) in multiples of 8 bytes
	},
	{ // DMABuffer;
		4096,	// BurstSizeB				Number of bytes to transfer in each DMA transaction (burst). - Range: 0 to (2^14 - 1) in multiples of 8
		1,		// BurstCount				Number of bursts to include in a single DMA page. - Range: 0 to 2^16 - 1
		1,	// PageCount				Number of pages to include in a single DMA buffer assigned to the channel. - Range: 0 to 1024
		1		// PagesPerMark				Number of pages between DMA markers. - Range: 0 to 1024, must divide evenly into PageCount (above)
											// Note: The above settings will create an 8 Mbyte DMA buffer spread across 128 pages (64 kbytes/page).  A DMA marker is set every 32 pages (2 Mbytes).
	}
};

// Initialize a default structure for the TX channels.
s_Channel TXDefault = {
	{ // Synchronizer
		1,	// StartEvent					Event that will activate the channel. - Range: 0 (none/immediate), 1 (software trigger), 2 (hardware trigger)
		3,	// StopEvent					Event that will deactivate the channel. - Range: 0 (flow control), 1 (software trigger), 2 (hardware trigger), 3 (sample count)
		16384	// SampleCount			Number of samples to process when sample count is selected for the synchronizer StartEvent. - Range: 0 to (2^32 - 1) in multiples of 8 bytes if data is not packetized
	},
	{ // DMABuffer;
		4096,	// BurstSizeB				Number of bytes to transfer in each DMA transaction (burst). - Range: 0 to (2^14 - 1) in multiples of 8
		16,		// BurstCount				Number of bursts to include in a single DMA page. - Range: 0 to 2^16 - 1
		128,	// PageCount				Number of pages to include in a single DMA buffer assigned to the channel. - Range: 0 to 1024
		32		// PagesPerMark				Number of pages between DMA markers. - Range: 1 to 1024, must divide evenly into PageCount (above)
											// Note: The above settings will create an 8 Mbyte DMA buffer spread across 128 pages (64 kbytes/page).  A DMA marker is set every 32 pages (2 Mbytes).
	}
};

// Initialize a default structure for the channel status interrupt mask.
s_ChannelIntMask ChannelMaskDefault = {
	1,	// DMA Marker						Generate an interrupt when the DMA marker is detected. - Range: 0 (disable) to 1 (enable)
	{ // Error
		0,	// Converter (ADC/DAC) Error	Generate an interrupt when a converter (ADC/DAC) error is detected. - Range: 0 (disable) to 1 (enable)
		0	// FIFO Error					Generate an interrupt when a FIFO error is detected. - Range: 0 (disable) to 1 (enable)
	}
};

#ifdef __cplusplus
}
#endif

#endif
